/**********************************************************************
 Freeciv - Copyright (C) 2005 - The Freeciv Project
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
***********************************************************************/

#include "fc_types.h"
#include "hash.h"

#include "script.h"

#include "api_store.h"

static struct hash_table *store;


void api_store_init(void)
{
  if (!store) {
    store = hash_new(hash_fval_string, hash_fcmp_string);
  }
}

void api_store_free(void)
{
  if (store) {
    hash_free(store);
    store = NULL;
  }
}

bool api_store_has_key(const char *key)
{
  if (!key) {
    script_error("nil string argument.");
    return FALSE;
  } else  {
    return hash_key_exists(store, key);
  }
}

int api_store_set(const char *key, int data)
{
  if (!key) {
    script_error("nil string argument.");
    return 0;
  } else {
    const void *key2;

    if (!hash_lookup(store, key, &key2, NULL)) {
      key2 = strdup(key); /* TODO: use sbuf */
    }
    return (int) hash_replace(store, key2, (void *) data);
  }
}

int api_store_pop(const char *key)
{
  if (!key) {
    script_error("nil string 'key' argument.");
    return 0;
  } else {
    int data = api_store_get(key);

    hash_delete_entry(store, key);
    return data;
  }
}

int api_store_get(const char *key)
{
  if (!key) {
    script_error("nil string 'key' argument.");
    return 0;
  } else {
    return (int) hash_lookup_data(store, key);
  }
}

